@@ -2,8 +2,8 @@
 
 #include  "Zevhnp.h"
 c            currently usable models
-      data RegMdls/'dpmjet3', 'nexus2', 'fritiof7.02', 'fritiof1.6',
-     *             'gheisha', 'nucrin', 'ad-hoc', 'incdpm3'/
+      data RegMdls/'dpmjet3', 'fritiof7.02', 'fritiof1.6',
+     *     'gheisha', 'nucrin', 'ad-hoc', 'incdpm3', 'qgsjet2'/
       
        data  
      * Cepic0 /0.00d0/ , 
