@@ -25,12 +25,11 @@ c                                     (in 'xyz')
        record /track/ Zfirst ! to keep first interaction info. V7.0
 c       real*8 Zfirst       ! to keep first interaction slant depth
        integer MoveStat    ! status code for moving a particle
-       real*8 TargetMassN  ! average target mass number. To be updated
-                           ! after a ptcl is moved.
-       real*8 TargetAtomicN   ! Average Z of the target.
+       real*8 TargetMassN  ! Number weighted average target mass number.  fixed value
+       real*8 TargetAtomicN   !The same for average Z of the target.   fixed value
        real*8 TargetZ2        ! <Z^2> of the target
-       integer TargetNucleonNo  !  target nucleon number at a collision
-       integer TargetProtonNo  !  target proton number  //
+       integer TargetNucleonNo  !  target nucleon number at a collision. sampled at each collision
+       integer TargetProtonNo  !  target proton number  //     //
        integer NumberOfInte ! Number of different kind of interactions 
                             ! considered for the current particle.
        integer ProcessNo   ! The process really happend is the
